#include <hidef.h> /* for EnableInterrupts macro */
#include "derivative.h" /* include peripheral declarations */

#define TpmDis 0xF8;		// prescalar set to 0
#define Div2	0x01;		// prescalar divide by 1
#define Div4	0x02;		// prescalar divide by 4
#define Div8	0x03;		// prescalar divide by 8
#define Div16	0x04;		// prescalar divide by 16
#define Div32	0x05;		// prescalar divide by 32
#define Div64	0x06;		// prescalar divide by 64


void delay(){
	if(TPMSC_TOF) {			// if overflow bit set
		TPMSC_TOF = !TPMSC_TOF_MASK;	//clear TOF
	}
	TPMSC |= Div4;						// start timer w/ busclk divided by 4
	while(!TPMSC_TOF);				// wait for overflow
	TPMSC &= TpmDis;					// disable timer
}

void main(void) {

	DisableInterrupts;				// disable interrupts
  
	// initialize target
	TPMMODH = 0xFF;			  	
	TPMMODL = 0xFF;					// max count value
	TPMC0SC = 0x00;					// TPM pin not used
	TPMSC = 0x08;						// BUSCLK input selected
  
	PTAD |= PTAD_PTAD3_MASK;		// set PTAD3 high
	PTADD |= PTADD_PTADD3_MASK;	// PTAD3 is output
  
	while(1){
  	
		delay();							// wait
  	
		PTAD ^= PTADD_PTADD3_MASK;	// toggle PTAD3
  }
  
  
  
}

/*         Function Prototypes          */

void delay(void);						// delay function